# Qiskit Provider for CTIC-Erwin

This repo contains a Qiskit provider based on **Qiskit Aer** that may be used to interact with the quantum simulation platform **Erwin** located at [CTIC](https://fundacionctic.org/).